package com.engine.organization.entity.department.bo;

import com.engine.organization.entity.department.po.DepartmentPO;
import com.engine.organization.entity.department.vo.SingleDeptTreeVO;
import com.engine.organization.mapper.department.DepartmentMapper;
import com.engine.organization.mapper.employee.EmployeeMapper;
import com.engine.organization.util.db.MapperProxyFactory;
import org.apache.commons.collections.CollectionUtils;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author weaver_cl
 * @Description: TODO
 * @Date 2022/5/20
 * @Version V1.0
 **/
public class DepartmentBO {

    public static List<SingleDeptTreeVO> buildSingleDeptTreeVOS(List<DepartmentPO> departmentPOs)  {

        if (CollectionUtils.isEmpty(departmentPOs)) {
            return Collections.emptyList();
        }


        List<SingleDeptTreeVO> singleDeptTreeVOS = departmentPOs.stream().map(e -> SingleDeptTreeVO.builder()
                .id(e.getId())
                .deptName(e.getDeptName())
                .parentDeptName(getDeptNameById(e.getParentDept()))
                .deptPrincipalName(getEmployeeNameById((long) e.getDeptPrincipal()))
                .children(recursiveData(e.getId()))
                .build()
        ).collect(Collectors.toList());

        return singleDeptTreeVOS;

    }


    public static String getDeptNameById(int id) {
       return MapperProxyFactory.getProxy(DepartmentMapper.class).getDeptNameById(id);
    }

    public static String getEmployeeNameById(Long id) {
        return MapperProxyFactory.getProxy(EmployeeMapper.class).getEmployeeNameById(id);
    }


    /**
     * 递归获取
     * @param parentDeptId
     * @return
     */
    public static List<SingleDeptTreeVO> recursiveData(long parentDeptId) {
        List<DepartmentPO> departmentPOS = MapperProxyFactory.getProxy(DepartmentMapper.class).getDeptListByPId(parentDeptId);
        if (CollectionUtils.isEmpty(departmentPOS)) {
            return Collections.emptyList();
        }

        List<SingleDeptTreeVO> singleDeptTreeVOS = departmentPOS.stream().map(e -> SingleDeptTreeVO.builder()
                    .id(e.getId())
                    .deptName(e.getDeptName())
                    .parentDeptName(getDeptNameById(e.getParentDept()))
                    .deptPrincipalName(getEmployeeNameById((long) e.getDeptPrincipal()))
                    .children(recursiveData(e.getId()))
                    .build()
            ).collect(Collectors.toList());

        return singleDeptTreeVOS;
    }



}
