package com.engine.organization.service.impl;

import com.api.browser.bean.BrowserBean;
import com.api.browser.bean.SearchConditionGroup;
import com.api.browser.bean.SearchConditionItem;
import com.cloudstore.eccom.result.WeaResultMsg;
import com.engine.core.impl.Service;
import com.engine.organization.component.OrganizationWeaTable;
import com.engine.organization.entity.QueryParam;
import com.engine.organization.entity.post.dto.PostInfoDTO;
import com.engine.organization.entity.post.param.PostInfoSearchParam;
import com.engine.organization.entity.post.po.PostInfoPO;
import com.engine.organization.entity.post.vo.PostInfoTableVO;
import com.engine.organization.mapper.post.PostInfoMapper;
import com.engine.organization.mapper.post.PostMapper;
import com.engine.organization.service.PostInfoService;
import com.engine.organization.util.MenuBtn;
import com.engine.organization.util.OrganizationAssert;
import com.engine.organization.util.OrganizationFormItemUtil;
import com.engine.organization.util.db.DBType;
import com.engine.organization.util.db.MapperProxyFactory;
import org.apache.commons.lang3.StringUtils;
import weaver.conn.RecordSet;
import weaver.general.StringUtil;
import weaver.general.Util;

import java.util.*;


/**
 * @description: TODO
 * @author:dxfeng
 * @createTime: 2022/05/13
 * @version: 1.0
 */
public class PostInfoServiceImpl extends Service implements PostInfoService {

    private PostInfoMapper getPostInfoMapper() {
        return MapperProxyFactory.getProxy(PostInfoMapper.class);
    }

    private PostMapper getPostMapper() {
        return MapperProxyFactory.getProxy(PostMapper.class);
    }

    @Override
    public Map<String, Object> listPage(Map<String, Object> params) {
        OrganizationWeaTable<PostInfoTableVO> table = new OrganizationWeaTable<>(user, PostInfoTableVO.class);
        String sqlWhere = buildSqlWhere(params);
        table.setSqlwhere(sqlWhere);
        WeaResultMsg result = new WeaResultMsg(false);
        result.putAll(table.makeDataResult());
        result.success();
        return result.getResultMap();
    }


    @Override
    public int savePostInfo(PostInfoSearchParam param) {
        List<PostInfoPO> list = getPostInfoMapper().listByNo(Util.null2String(param.getPostInfoNo()));
        OrganizationAssert.isEmpty(list, "编号不允许重复");
        PostInfoPO postInfoPO = PostInfoDTO.convertParamToPO(param, (long) user.getUID());
        return getPostInfoMapper().insertIgnoreNull(postInfoPO);
    }

    @Override
    public int updatePostInfo(PostInfoSearchParam param) {
        PostInfoPO postInfoPO = PostInfoDTO.convertParamToPO(param, (long) user.getUID());
        return getPostInfoMapper().updatePostInfo(postInfoPO);
    }

    @Override
    public int updateForbiddenTagById(PostInfoSearchParam params) {
        PostInfoPO postInfoPO = PostInfoPO.builder().id(params.getId()).forbiddenTag(params.getForbiddenTag() ? 0 : 1).build();
        return getPostInfoMapper().updateForbiddenTagById(postInfoPO);
    }


    @Override
    public int deleteByIds(Collection<Long> ids) {
        OrganizationAssert.notEmpty(ids, "请选择要删除的数据");
        return getPostInfoMapper().deleteByIds(ids);
    }


    @Override
    public Map<String, Object> getSearchCondition(Map<String, Object> params) {
        Map<String, Object> apiDatas = new HashMap<>();
        List<SearchConditionGroup> addGroups = new ArrayList<>();
        List<SearchConditionItem> conditionItems = new ArrayList<>();
        SearchConditionItem browserItem = OrganizationFormItemUtil.browserItem(user, 2, 16, 2, false, "职务分类", "161", "postId", "postBrowser");
        SearchConditionItem nameCondition = OrganizationFormItemUtil.inputItem(user, 2, 16, 2, 50, "名称", "postInfoName");
        conditionItems.add(browserItem);
        conditionItems.add(nameCondition);
        addGroups.add(new SearchConditionGroup("高级搜索条件", true, conditionItems));
        apiDatas.put("conditions", addGroups);
        return apiDatas;
    }


    @Override
    public Map<String, Object> getPostInfoForm(Map<String, Object> params) {
        Map<String, Object> apiDatas = new HashMap<>();
        List<SearchConditionItem> selectItems = new ArrayList<>();
        List<SearchConditionGroup> addGroups = new ArrayList<>();
        // 编号
        SearchConditionItem noItem = OrganizationFormItemUtil.inputItem(user, 2, 17, 3, 50, "编号", "postInfoNo");
        noItem.setRules("required|string");
        // 名称
        SearchConditionItem nameItem = OrganizationFormItemUtil.inputItem(user, 2, 17, 3, 50, "名称", "postInfoName");
        nameItem.setRules("required|string");
        // 权限
        SearchConditionItem authorityItem = OrganizationFormItemUtil.inputItem(user, 2, 17, 2, 50, "权限", "postInfoAuthority");
        // 责任
        SearchConditionItem dutyItem = OrganizationFormItemUtil.inputItem(user, 2, 17, 2, 50, "责任", "postInfoDuty");
        // 资格
        SearchConditionItem qualificationItem = OrganizationFormItemUtil.inputItem(user, 2, 17, 2, 50, "资格", "postInfoQualification");
        // 职务分类
        SearchConditionItem postIdBrowser = OrganizationFormItemUtil.browserItem(user, 2, 17, 3, false, "职务分类", "161", "postId", "postBrowser");
        postIdBrowser.setRules("required|string");
        // 说明
        SearchConditionItem descriptionItem = OrganizationFormItemUtil.textareaItem(user, 2, 17, true, 2, 60, "描述说明", "description");

        // 编辑状态下赋值操作
        String id = Util.null2String(params.get("id"));
        if (!StringUtil.isEmpty(id)) {
            PostInfoPO postInfoPO = getPostInfoMapper().getPostInfoByID(Integer.parseInt(id));
            OrganizationAssert.notNull(postInfoPO, "选择的数据不存在，或数据已删除");

            noItem.setValue(postInfoPO.getPostInfoNo());
            nameItem.setValue(postInfoPO.getPostInfoName());
            authorityItem.setValue(postInfoPO.getPostInfoAuthority());
            dutyItem.setValue(postInfoPO.getPostInfoDuty());
            qualificationItem.setValue(postInfoPO.getPostInfoQualification());
            descriptionItem.setValue(postInfoPO.getDescription());

            BrowserBean browserBean = postIdBrowser.getBrowserConditionParam();
            List<Map<String, Object>> maps = getPostMapper().listPostsByIds(QueryParam.builder().ids(postInfoPO.getPostId().toString()).build().getIds());

            browserBean.setReplaceDatas(maps);
            postIdBrowser.setBrowserConditionParam(browserBean);
            // 编辑状态下,编号只读
            noItem.setViewAttr(1);
        }

        selectItems.add(noItem);
        selectItems.add(nameItem);
        selectItems.add(authorityItem);
        selectItems.add(dutyItem);
        selectItems.add(qualificationItem);
        selectItems.add(postIdBrowser);
        selectItems.add(descriptionItem);
        addGroups.add(new SearchConditionGroup("基本信息", true, selectItems));
        apiDatas.put("condition", addGroups);
        return apiDatas;
    }

    @Override
    public Map<String, Object> getHasRight() {
        return MenuBtn.getCommonBtnDatas();
    }


    /**
     * 查询条件
     *
     * @param params
     * @return
     */
    private String buildSqlWhere(Map<String, Object> params) {
        DBType dbType = DBType.get(new RecordSet().getDBType());
        String sqlWhere = " where t.delete_type ='0' ";
        String sequenceName = (String) params.get("postInfoName");
        if (StringUtils.isNotBlank(sequenceName)) {
            sqlWhere += " AND t.post_info_name " + dbType.like(sequenceName);
        }
        String postId = (String) params.get("postId");
        if (StringUtils.isNotBlank(postId) && !"-1".equals(postId)) {
            sqlWhere += " AND t.post_id ='" + postId + "'";
        }
        return sqlWhere;
    }
}
