package com.engine.organization.web;

import com.engine.common.util.ParamUtil;
import com.engine.common.util.ServiceUtil;
import com.engine.organization.entity.QueryParam;
import com.engine.organization.entity.scheme.param.LevelSearchParam;
import com.engine.organization.util.response.ReturnResult;
import com.engine.organization.wrapper.LevelWrapper;
import io.swagger.v3.oas.annotations.parameters.RequestBody;
import weaver.hrm.HrmUserVarify;
import weaver.hrm.User;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import java.util.Map;

/**
 * @description: TODO
 * @author:dxfeng
 * @createTime: 2022/05/10
 * @version: 1.0
 */
public class LevelController {
    public LevelWrapper getLevelWrapper(User user) {
        return ServiceUtil.getService(LevelWrapper.class, user);
    }

    /**
     * 获取list列表
     *
     * @param request
     * @param response
     * @return
     */
    @GET
    @Path("/getLevelTable")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult listLevel(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            Map<String, Object> map = ParamUtil.request2Map(request);
            return ReturnResult.successed(getLevelWrapper(user).listPage(map));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 添加职等
     *
     * @param request
     * @param response
     * @return
     */
    @POST
    @Path("/saveLevel")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult saveLevel(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody LevelSearchParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).saveLevel(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 更新职等，修改所有字段
     *
     * @param request
     * @param response
     * @param param
     * @return
     */
    @POST
    @Path("/updateLevel")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult updateLevel(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody LevelSearchParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).updateLevel(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 更新禁用标记
     *
     * @param request
     * @param response
     * @param param
     * @return
     */
    @POST
    @Path("/updateForbiddenTagById")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult updateForbiddenTagById(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody LevelSearchParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).updateForbiddenTagById(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }


    /**
     * 根据ID批量删除数据
     *
     * @param request
     * @param response
     * @param param
     * @return
     */
    @POST
    @Path("/deleteByIds")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult deleteByIds(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody QueryParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).deleteByIds(param.getIds()));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 高级搜索条件
     *
     * @param request
     * @param response
     * @return
     */
    @GET
    @Path("/getSearchCondition")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getSearchCondition(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            Map<String, Object> map = ParamUtil.request2Map(request);
            return ReturnResult.successed(getLevelWrapper(user).getSearchCondition(map));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }


    /**
     * 新增、编辑表单
     *
     * @param request
     * @param response
     * @return
     */
    @GET
    @Path("/getLevelForm")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getLevelForm(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            Map<String, Object> map = ParamUtil.request2Map(request);
            return ReturnResult.successed(getLevelWrapper(user).getLevelForm(map));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 列表页顶部按钮
     *
     * @param request
     * @param response
     * @return
     */
    @GET
    @Path("/getTableBtn")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getTableBtn(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).getTableBtn());
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @GET
    @Path("/getTabInfo")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getTabInfo(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getLevelWrapper(user).getTabInfo());
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }
}
